@@ -5,9 +5,6 @@ import logging
 import os
 from json import JSONDecodeError
 
-import boto3
-from botocore.config import Config
-from cachetools import TTLCache
 from requests import request
 
 from sp_api.auth import AccessTokenClient, AccessTokenResponse
@@ -15,16 +12,12 @@ from .ApiResponse import ApiResponse
 from .base_client import BaseClient
 from .exceptions import get_exception_for_code, MissingScopeException
 from .marketplaces import Marketplaces
-from sp_api.base import AWSSigV4
 from sp_api.base.credential_provider import CredentialProvider
 
 log = logging.getLogger(__name__)
 
-role_cache = TTLCache(maxsize=int(os.environ.get('SP_API_AUTH_CACHE_SIZE', 10)), ttl=3200)
-
 
 class Client(BaseClient):
-    boto3_client = None
     grantless_scope: str = ''
     keep_restricted_data_token: bool = False
     version = None
@@ -51,17 +44,7 @@ class Client(BaseClient):
             credentials,
             credential_providers=credential_providers,
         ).credentials
-        boto_config = Config(
-            proxies=proxies,
-        )
-        session = boto3.session.Session()
-        self.boto3_client = session.client(
-            'sts',
-            aws_access_key_id=self.credentials.aws_access_key,
-            aws_secret_access_key=self.credentials.aws_secret_key,
-            config=boto_config,
-            verify=verify,
-        )
+
         self.endpoint = marketplace.endpoint
         self.marketplace_id = marketplace.marketplace_id
         self.region = marketplace.region
@@ -72,19 +55,6 @@ class Client(BaseClient):
         self.version = version
         self.verify = verify
 
-    def _get_cache_key(self, token_flavor=''):
-        return 'role_' + hashlib.md5(
-            (token_flavor + self._auth.cred.refresh_token).encode('utf-8')
-        ).hexdigest()
-
-    def set_role(self, cache_key='role'):
-        role = self.boto3_client.assume_role(
-            RoleArn=self.credentials.role_arn,
-            RoleSessionName='guid'
-        )
-        role_cache[cache_key] = role
-        return role
-
     @property
     def headers(self):
         return {
@@ -105,31 +75,6 @@ class Client(BaseClient):
             raise MissingScopeException("Grantless operations require scope")
         return self._auth.get_grantless_auth(self.grantless_scope)
 
-    @property
-    def role(self):
-        cache_key = self._get_cache_key()
-        try:
-            role = role_cache[cache_key]
-        except KeyError:
-            role = self.set_role(cache_key)
-        return role.get('Credentials')
-
-    def _sign_request(self):
-        aws_session_token = None
-        aws_access_key_id = self.credentials.aws_access_key
-        aws_secret_access_key = self.credentials.aws_secret_key
-        if self.credentials.role_arn:
-            role = self.role
-            aws_session_token = role.get('SessionToken')
-            aws_access_key_id = role.get('AccessKeyId')
-            aws_secret_access_key = role.get('SecretAccessKey')
-        return AWSSigV4('execute-api',
-                        aws_access_key_id=aws_access_key_id,
-                        aws_secret_access_key=aws_secret_access_key,
-                        region=self.region,
-                        aws_session_token=aws_session_token
-                        )
-
     def _request(self, path: str, *, data: dict = None, params: dict = None, headers=None,
                  add_marketplace=True, res_no_data: bool = False, bulk: bool = False,
                  wrap_list: bool = False) -> ApiResponse:
@@ -150,7 +95,6 @@ class Client(BaseClient):
                       params=params,
                       data=json.dumps(data) if data and self.method in ('POST', 'PUT', 'PATCH') else None,
                       headers=headers or self.headers,
-                      auth=self._sign_request(),
                       timeout=self.timeout,
                       proxies=self.proxies,
                       verify=self.verify)
